==> xmule-1.9.0.tar.bz2: xmule-1.9.0/src/PPgStats.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef PPGSTATS_H
#define PPGSTATS_H

#include "Preferences.h"                // Needed for CPreferences
#include <wx/panel.h>                   // Needed for wxPanel
#include <wx/combobox.h>                // Needed for wxComboBox

class CPPgStats : public wxPanel
{
  //DECLARE_DYNAMIC(CPPgStats)
  DECLARE_DYNAMIC_CLASS(CPPgStats)
    CPPgStats() {};
public:
	CPPgStats(wxWindow* parent);
	virtual ~CPPgStats();

	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs; }

// Dialog Data
	enum
        {
            IDD_PPG_STATS,
            IDD = IDD_PPG_STATS
        };
protected:
	CPreferences *app_prefs;
protected:
#if 0
	//{{AFX_MSG(CSpinToolBar)
	afx_msg void OnHScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	//}}AFX_MSG
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	DECLARE_MESSAGE_MAP()
#endif
	  DECLARE_EVENT_TABLE()
	wxComboBox* m_colors;
	void OnHScroll(wxScrollEvent& evt);
	void OnCbnSelchangeColorselector(wxCommandEvent& evt);
	void ShowInterval();
	void OnChangeColor(wxEvent& evt);
public:
	//virtual BOOL OnInitDialog();
private:
	int mystats1,mystats2,mystats3;
public:
	virtual BOOL OnApply();
	void Localize(void);
	void LoadSettings();
};

#endif

==> xmule-1.9.1b.tar.bz2: xmule-1.9.1b/src/PPgStats.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef PPGSTATS_H
#define PPGSTATS_H

#include <wx/panel.h>                       // Needed for wxPanel

class CPreferences;
class wxComboBox;

class CPPgStats : public wxPanel
{
  DECLARE_DYNAMIC_CLASS(CPPgStats)
    CPPgStats() {};
public:
	CPPgStats(wxWindow* parent);
	virtual ~CPPgStats();

	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs; }

// Dialog Data
	enum
        {
            IDD_PPG_STATS,
            IDD = IDD_PPG_STATS
        };
protected:
	CPreferences *app_prefs;
protected:
  DECLARE_EVENT_TABLE()
	wxComboBox* m_colors;
	void OnHScroll(wxScrollEvent& evt);
	void OnCbnSelchangeColorselector(wxCommandEvent& evt);
	void ShowInterval();
	void OnChangeColor(wxCommandEvent & evt);
private:
	int mystats1,mystats2,mystats3;
public:
	virtual bool OnApply();
	void Localize(void);
	void LoadSettings();
};

#endif
